# -*- coding: utf-8 -*-
"""
    revision_gcs
    ~~~~~~~~~~~~

    :copyright: (c) 2017 by COLORFUL BOARD Inc.
    :license: MIT, see LICENSE for more details.
"""

from __future__ import absolute_import

__version__ = "0.0.5"
__license__ = "MIT"

from .client import GCSClient  # noqa: F401
